@@ -324,8 +324,12 @@ fr_command_7z_add (FrCommand     *comm,
 		fr_process_add_arg_concat (comm->process, "-w", base_dir, NULL);
 	}
 
-	if (is_mime_type (comm->mime_type, "application/zip"))
+	if (is_mime_type (comm->mime_type, "application/zip")
+	    || is_mime_type (comm->mime_type, "application/x-cbz"))
+	{
 		fr_process_add_arg (comm->process, "-tzip");
+		fr_process_add_arg (comm->process, "-mem=AES128");
+	}
 
 	fr_process_add_arg (comm->process, "-bd");
 	fr_process_add_arg (comm->process, "-y");
@@ -546,10 +550,14 @@ fr_command_7z_get_capabilities (FrCommand  *comm,
 		return capabilities;
 
 	if (is_mime_type (mime_type, "application/x-7z-compressed")) {
-		capabilities |= FR_COMMAND_CAN_READ_WRITE | FR_COMMAND_CAN_ENCRYPT | FR_COMMAND_CAN_ENCRYPT_HEADER | FR_COMMAND_CAN_CREATE_VOLUMES;
+		capabilities |= FR_COMMAND_CAN_READ_WRITE | FR_COMMAND_CAN_CREATE_VOLUMES;
+		if (is_program_available ("7z", check_command))
+			capabilities |= FR_COMMAND_CAN_ENCRYPT | FR_COMMAND_CAN_ENCRYPT_HEADER;
 	}
 	else if (is_mime_type (mime_type, "application/x-7z-compressed-tar")) {
-		capabilities |= FR_COMMAND_CAN_READ_WRITE | FR_COMMAND_CAN_ENCRYPT | FR_COMMAND_CAN_ENCRYPT_HEADER | FR_COMMAND_CAN_CREATE_VOLUMES;
+		capabilities |= FR_COMMAND_CAN_READ_WRITE;
+		if (is_program_available ("7z", check_command))
+			capabilities |= FR_COMMAND_CAN_ENCRYPT | FR_COMMAND_CAN_ENCRYPT_HEADER;
 	}
 	else if (is_program_available ("7z", check_command)) {
 		if (is_mime_type (mime_type, "application/x-rar")
@@ -592,11 +600,11 @@ fr_command_7z_get_packages (FrCommand  *comm,
 			    const char *mime_type)
 {
 	if (is_mime_type (mime_type, "application/x-rar"))
-		return "p7zip,p7zip-rar";
+		return PACKAGES ("p7zip,p7zip-rar");
 	else if (is_mime_type (mime_type, "application/zip") || is_mime_type (mime_type, "application/vnd.ms-cab-compressed"))
-		return "p7zip,p7zip-full";
+		return PACKAGES ("p7zip,p7zip-full");
 	else
-		return "p7zip";
+		return PACKAGES ("p7zip");
 }
 
 
